ports/145106: [PATCH] unbreak graphics/xli (libpng upgrade fallout)

Christoph Moench-Tegeder cmt at burggraben.net
Sun Mar 28 11:20:03 UTC 2010


>Number:         145106
>Category:       ports
>Synopsis:       [PATCH] unbreak graphics/xli (libpng upgrade fallout)
>Confidential:   no
>Severity:       serious
>Priority:       medium
>Responsible:    freebsd-ports-bugs
>State:          open
>Quarter:        
>Keywords:       
>Date-Required:
>Class:          sw-bug
>Submitter-Id:   current-users
>Arrival-Date:   Sun Mar 28 11:20:02 UTC 2010
>Closed-Date:
>Last-Modified:
>Originator:     Christoph Moench-Tegeder
>Release:        FreeBSD 8.0-RELEASE-p2 amd64
>Organization:
>Environment:
System: FreeBSD elch.exwg.net 8.0-RELEASE-p2 FreeBSD 8.0-RELEASE-p2 #8: Sat Feb 20 21:36:50 CET 2010 cmt at elch.exwg.net:/usr/obj/usr/src/sys/CMT amd64

	png-1.4.1
	xli-1.17.0_8 (upgrading to xli-1.17.0_9)
>Description:
	Build of graphics/xli fails because libpng 1.4 forces use of
	png_sig_cmp() instead of the old png_check_sig() ("undefined reference"
	linker error)
>How-To-Repeat:
	run portupgrade
>Fix:

	Add graphics/xli/files/patch-png.c
	(also available at http://burggraben.net/hacks/patch-png.c )

--- png.c.orig	2010-03-28 13:05:30.000000000 +0200
+++ png.c	2010-03-28 13:06:28.000000000 +0200
@@ -11,7 +11,7 @@
 
 #define TITLE_KEYWORD "Title"
 
 /* check to see if a file is a png file using png_check_sig() */
 static int check_png(char *file_name)
 {
 	ZFILE *zfp;
@@ -27,7 +27,7 @@
 	if (ret != 8)
 		return 0;
 
-	ret = png_check_sig(buf, 8);
+	ret = png_sig_cmp(buf, 0, 8);
 
 	return (ret);
 }
@@ -11,7 +11,7 @@
 #define TITLE_KEYWORD "Title"
 
-/* check to see if a file is a png file using png_check_sig() */
+/* check to see if a file is a png file using png_sig_cmp() */
 static int check_png(char *file_name)
 {


>Release-Note:
>Audit-Trail:
>Unformatted:



More information about the freebsd-ports-bugs mailing list